#
# spec file for package python-radon
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-radon
Version:        3.0.1
Release:        3.1
Summary:        Code Metrics in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/rubik/radon
Source:         https://files.pythonhosted.org/packages/source/r/radon/radon-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-colorama >= 0.4
Requires:       python-flake8-polyfill
Requires:       python-mando >= 0.6
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module colorama >= 0.4}
BuildRequires:  %{python_module flake8-polyfill}
BuildRequires:  %{python_module mando >= 0.6}
BuildRequires:  %{python_module pytest >= 2.7}
BuildRequires:  %{python_module pytest-mock}
# /SECTION
%python_subpackages

%description
Radon is a Python tool that computes various metrics from the source code.
Radon can compute:

* McCabe's complexity**, i.e. cyclomatic complexity
* raw metrics (these include SLOC, comment lines, blank lines, &c.)
* Halstead metrics (all of them)
* Maintainability Index (the one used in Visual Studio)

%prep
%setup -q -n radon-%{version}

%build
%python_build
rm -r */lib/radon/tests

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/radon

%check
export LANG=en_US.UTF-8
%python_exec -m pytest --strict

%post
%python_install_alternative radon

%postun
%python_uninstall_alternative radon

%files %{python_files}
%doc CHANGELOG README.rst
%license LICENSE
%python_alternative %{_bindir}/radon
%{python_sitelib}/*

%changelog
* Tue Mar  5 2019 hpj@urpla.net
- set environment encoding for checks in order to succeed
  test_encoding with Python < 3.7
* Thu Feb 14 2019 jayvdb@gmail.com
- Fix tests which were erroring but the error was being ignored
- Remove tests from the package
- Use GitHub repository for the link, as it has links to other
  resources
- Update to v3.0.1
  * Automatically exclude binary files, instead of producing an error
- from 3.0.0
  * Include files with no extension but a Python shebang
  * Fix calculation of total complexity for classes
  * Update Colorama dependency to avoid conflicts with pytest
  * Fix raw metrics, which were completely broken
* Sat Jan 19 2019 michael@stroeder.com
- Update to 2.4.0
  * No upstream changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 2.2.0
  * Add an option to show closures when Radon is used from flake8: #135
- spec file cleanups
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
